:- module mod_a.sub1.
:- interface.

    % The bug occurs when bbb is only visible via the import in the parent
    % module instead of this import.
%:- import_module mod_a.sub2.

:- type struct
    --->    struct(
                s_field1 :: int,
                s_field2 :: sub2.bbb
            ).
