:- module bugmain.
:- interface.

:- import_module mod_a.
:- import_module mod_a.sub1.

:- pred get_field1(struct::in, int::out) is det.

:- implementation.

get_field1(Struct, F1) :-
    F1 = Struct ^ s_field1.
